ComplexSeparatedCombination
===========================

.. currentmodule:: pykeen.nn.combination

.. autoclass:: ComplexSeparatedCombination
   :show-inheritance:

   .. rubric:: Methods Summary

   .. autosummary::

      ~ComplexSeparatedCombination.forward
      ~ComplexSeparatedCombination.output_shape

   .. rubric:: Methods Documentation

   .. automethod:: forward
   .. automethod:: output_shape
